@@ -34,7 +34,8 @@ class Connector(object):
     def __init__(
             self, url, username=None, password=None, verify=True,
             response_callback=None, server_side_retries=0,
-            server_side_retries_delay=0):
+            server_side_retries_delay=0,
+            default_request_timeout=60):
         self._url = url
         self._verify = verify
         self._session = requests.Session()
@@ -42,6 +43,7 @@ class Connector(object):
         self._auth = None
         self._server_side_retries = server_side_retries
         self._server_side_retries_delay = server_side_retries_delay
+        self._default_request_timeout = default_request_timeout
 
         # NOTE(TheJulia): In order to help prevent recursive post operations
         # by allowing us to understand that we should stop authentication.
@@ -51,15 +53,6 @@ class Connector(object):
         # By default, we ask HTTP server to shut down HTTP connection we've
         # just used.
         self._session.headers['Connection'] = 'close'
-        # NOTE(TheJulia): Depending on the BMC, offering compression as an
-        # acceptable response changes the ETag behavior to offering an
-        # automatic "weak" ETag response, which is appropriate because the
-        # body content *may* not be a byte for byte match given compression.
-        # Overall, the value of compression is less than the value of concise
-        # interaction with the BMC. Setting to identity basically means
-        # "without modification or compression". By default, python-requests
-        # indicates responses can be compressed.
-        self._session.headers['Accept-Encoding'] = 'identity'
 
         if username or password:
             LOG.warning('Passing username and password to Connector is '
@@ -107,7 +100,7 @@ class Connector(object):
         return retry
 
     def _op(self, method, path='', data=None, headers=None, blocking=False,
-            timeout=60, server_side_retries_left=None, allow_reauth=True,
+            timeout=None, server_side_retries_left=None, allow_reauth=True,
             **extra_session_req_kwargs):
         """Generic RESTful request handler.
 
@@ -115,13 +108,13 @@ class Connector(object):
             PUT, PATCH, etc...
         :param path: The sub-URI or absolute URL path to the resource.
         :param data: Optional JSON data.
-        :param headers: Optional dictionary of headers.
+        :param headers: Optional dictionary of headers. Use None value
+                        to remove a default header.
         :param blocking: Whether to block for asynchronous operations.
         :param timeout: Max time in seconds to wait for blocking async call or
-                        for requests library to connect and read. If a custom
-                        timeout for requests is provided in
-                        extra_session_req_kwargs, it will be used instead for
-                        those calls.
+                        for requests library to connect and read. Timeouts
+                        should never be disabled: set to a large enough value
+                        instead.
         :param server_side_retries_left: Remaining retries. If not provided
             will use limit provided by instance's server_side_retries
         :param allow_reauth: Whether to allow refreshing the authentication
@@ -136,14 +129,29 @@ class Connector(object):
         if server_side_retries_left is None:
             server_side_retries_left = self._server_side_retries
 
+        timeout = timeout or self._default_request_timeout
+
         url = path if urlparse.urlparse(path).netloc else urlparse.urljoin(
             self._url, path)
-        headers = headers or {}
+        headers = (headers or {}).copy()
         lc_headers = [k.lower() for k in headers]
         if data is not None and 'content-type' not in lc_headers:
             headers['Content-Type'] = 'application/json'
         if 'odata-version' not in lc_headers:
             headers['OData-Version'] = '4.0'
+        # NOTE(TheJulia): Depending on the BMC, offering compression as an
+        # acceptable response changes the ETag behavior to offering an
+        # automatic "weak" ETag response, which is appropriate because the
+        # body content *may* not be a byte for byte match given compression.
+        # Overall, the value of compression is less than the value of concise
+        # interaction with the BMC. Setting to identity basically means
+        # "without modification or compression". By default, python-requests
+        # indicates responses can be compressed.
+        if 'accept-encoding' not in lc_headers:
+            headers['Accept-Encoding'] = 'identity'
+        # Allow removing default headers
+        headers = {k: v for k, v in headers.items() if v is not None}
+
         # TODO(lucasagomes): We should mask the data to remove sensitive
         # information
         LOG.debug('HTTP request: %(method)s %(url)s; headers: %(headers)s; '
@@ -187,7 +195,7 @@ class Connector(object):
                           'Please check credentials and try again.')
                 raise
             if not allow_reauth:
-                LOG.error("Failure occured while attempting to retry "
+                LOG.error("Failure occurred while attempting to retry "
                           "request after refreshing the session: %s", e)
                 raise
             if self._auth is not None:
@@ -211,7 +219,7 @@ class Connector(object):
                                     're-authenticate.')
                         self._auth.authenticate()
                 except exceptions.AccessError as refresh_exc:
-                    LOG.error("A failure occured while attempting to refresh "
+                    LOG.error("A failure occurred while attempting to refresh "
                               "the session. Error: %s", refresh_exc.message)
                     raise
                 LOG.debug("Authentication refreshed successfully, "
@@ -268,6 +276,21 @@ class Connector(object):
                     **extra_session_req_kwargs)
             else:
                 raise
+        except exceptions.NotAcceptableError as e:
+            # NOTE(dtantsur): some HPE Gen 10 Plus machines do not allow
+            # identity encoding when fetching registries.
+            if (method.lower() == 'get'
+                    and headers.get('Accept-Encoding') == 'identity'):
+                LOG.warning('Server has indicated a NotAcceptable for %s, '
+                            'retrying without identity encoding', e)
+                headers = dict(headers, **{'Accept-Encoding': None})
+                return self._op(
+                    method, path, data=data, headers=headers,
+                    blocking=blocking, timeout=timeout,
+                    server_side_retries_left=server_side_retries_left,
+                    **extra_session_req_kwargs)
+            else:
+                raise
         if blocking and response.status_code == 202:
             if not response.headers.get('Location'):
                 m = ('HTTP response for %(method)s request to %(url)s '
@@ -288,7 +311,7 @@ class Connector(object):
         return response
 
     def get(self, path='', data=None, headers=None, blocking=False,
-            timeout=60, **extra_session_req_kwargs):
+            timeout=None, **extra_session_req_kwargs):
         """HTTP GET method.
 
         :param path: Optional sub-URI path to the resource.
@@ -296,6 +319,7 @@ class Connector(object):
         :param headers: Optional dictionary of headers.
         :param blocking: Whether to block for asynchronous operations.
         :param timeout: Max time in seconds to wait for blocking async call.
+                        Defaults to default_request_timeout on Connector.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
@@ -308,7 +332,7 @@ class Connector(object):
                         **extra_session_req_kwargs)
 
     def post(self, path='', data=None, headers=None, blocking=False,
-             timeout=60, **extra_session_req_kwargs):
+             timeout=None, **extra_session_req_kwargs):
         """HTTP POST method.
 
         :param path: Optional sub-URI path to the resource.
@@ -316,6 +340,7 @@ class Connector(object):
         :param headers: Optional dictionary of headers.
         :param blocking: Whether to block for asynchronous operations.
         :param timeout: Max time in seconds to wait for blocking async call.
+                        Defaults to default_request_timeout on Connector.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
@@ -328,7 +353,8 @@ class Connector(object):
                         **extra_session_req_kwargs)
 
     def _etag_handler(self, path='', data=None, headers=None, etag=None,
-                      blocking=False, timeout=60, **extra_session_req_kwargs):
+                      blocking=False, timeout=None,
+                      **extra_session_req_kwargs):
         """eTag handler containing workarounds for PATCH requests with eTags.
 
         :param path: Optional sub-URI path to the resource.
@@ -337,6 +363,7 @@ class Connector(object):
         :param etag: eTag string.
         :param blocking: Whether to block for asynchronous operations.
         :param timeout: Max time in seconds to wait for blocking async call.
+                        Defaults to default_request_timeout on Connector.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
@@ -407,7 +434,7 @@ class Connector(object):
         return response
 
     def patch(self, path='', data=None, headers=None, etag=None,
-              blocking=False, timeout=60, **extra_session_req_kwargs):
+              blocking=False, timeout=None, **extra_session_req_kwargs):
         """HTTP PATCH method.
 
         :param path: Optional sub-URI path to the resource.
@@ -416,6 +443,7 @@ class Connector(object):
         :param etag: Optional eTag string.
         :param blocking: Whether to block for asynchronous operations.
         :param timeout: Max time in seconds to wait for blocking async call.
+                        Defaults to default_request_timeout on Connector.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
@@ -429,7 +457,7 @@ class Connector(object):
                                   **extra_session_req_kwargs)
 
     def put(self, path='', data=None, headers=None, blocking=False,
-            timeout=60, **extra_session_req_kwargs):
+            timeout=None, **extra_session_req_kwargs):
         """HTTP PUT method.
 
         :param path: Optional sub-URI path to the resource.
@@ -437,6 +465,7 @@ class Connector(object):
         :param headers: Optional dictionary of headers.
         :param blocking: Whether to block for asynchronous operations.
         :param timeout: Max time in seconds to wait for blocking async call.
+                        Defaults to default_request_timeout on Connector.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
@@ -449,7 +478,7 @@ class Connector(object):
                         **extra_session_req_kwargs)
 
     def delete(self, path='', data=None, headers=None, blocking=False,
-               timeout=60, **extra_session_req_kwargs):
+               timeout=None, **extra_session_req_kwargs):
         """HTTP DELETE method.
 
         :param path: Optional sub-URI path to the resource.
@@ -457,6 +486,7 @@ class Connector(object):
         :param headers: Optional dictionary of headers.
         :param blocking: Whether to block for asynchronous operations.
         :param timeout: Max time in seconds to wait for blocking async call.
+                        Defaults to default_request_timeout on Connector.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
