@@ -17,13 +17,12 @@ import abc
 import collections
 import copy
 import enum
+from importlib import resources
 import io
 import json
 import logging
 import zipfile
 
-import pkg_resources
-
 from sushy import exceptions
 from sushy.resources import constants
 from sushy.resources import oem
@@ -104,7 +103,7 @@ class Field(object):
 
                 logging.warning(
                     'Applying default "%s" on required, but missing '
-                    'attribute "%s"' % (self._default, path))
+                    'attribute "%s"', self._default, path)
 
             # Do not run the adapter on the default value
             return self._default
@@ -423,9 +422,13 @@ class JsonDataReader(AbstractDataReader):
     def get_data(self):
         """Gets JSON file from URI directly"""
         data = self._conn.get(path=self._path)
-
-        json_data = data.json() if data.content else {}
-
+        try:
+            json_data = data.json() if data.content else {}
+        except Exception as exc:
+            LOG.error("Unable to parse JSON in response. %(exc)s. The server "
+                      "returned:\n%(data)s",
+                      {'exc': exc, 'data': data.content})
+            raise
         return FieldData(data.status_code, data.headers, json_data)
 
 
@@ -482,9 +485,9 @@ class JsonPackagedFileReader(AbstractDataReader):
     def get_data(self):
         """Gets JSON file from packaged file denoted by path"""
 
-        with pkg_resources.resource_stream(self._resource_package_name,
-                                           self._path) as resource:
-            json_data = json.loads(resource.read().decode(encoding='utf-8'))
+        ref = resources.files(self._resource_package_name).joinpath(self._path)
+        with ref.open(encoding='utf-8') as fp:
+            json_data = json.load(fp)
             return FieldData(None, None, json_data)
 
 
